@@ -1,6 +1,6 @@
 package Test::HTTP::Server::Simple;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use warnings;
 use strict;
@@ -45,9 +45,7 @@ Test::HTTP::Server::Simple - Test::More functions for HTTP::Server::Simple
 This mixin class provides methods to test an L<HTTP::Server::Simple>-based web
 server.  Currently, it provides only one such method: C<started_ok>.
 
-=over 4 
-
-=item started_ok [$text]
+=head2 started_ok [$text]
 
 C<started_ok> takes 
 an optional test description.  The server needs to have been configured (specifically,
@@ -72,6 +70,7 @@ my @CHILD_PIDS;
 $SIG{INT} = sub { warn "INT:$$"; exit };
 
 END {
+    local $?;
     if (WIN32) {
         # INT won't do since the server is doing a blocking read
         # which isn't interrupted by anything but KILL on win32.
@@ -82,8 +81,17 @@ END {
         }
     }
     else {
-        kill 'USR1', @CHILD_PIDS if @CHILD_PIDS;
-        wait for @CHILD_PIDS;
+        while (@CHILD_PIDS) {
+            kill 'USR1', @CHILD_PIDS;
+            local $SIG{ALRM} = sub {die};
+            alarm(5);
+            eval {
+                my $pid;
+                @CHILD_PIDS = grep {$_ != $pid} @CHILD_PIDS
+                  while $pid = wait and $pid > 0 and @CHILD_PIDS;
+            };
+            alarm(0);
+        }
     }
 } 
 
@@ -170,9 +178,19 @@ sub setup_listener {
     else {
         kill 'USR1', $self->{'test_http_server_simple_parent_pid'};
     }
-} 
+}
 
-=back
+=head2 pids
+
+Returns the PIDs of the processes which have been started.  Since
+multiple test servers can be running at one, be aware that this
+returns a list.
+
+=cut
+
+sub pids {
+    return @CHILD_PIDS;
+}
 
 =head1 DEPENDENCIES
 
